add.species.to.genus(tree, species, genus=NULL, where=c("root","random"))"phylo"."Genus_species" or "Genus species".species is to be attached. If NULL then genus will be extracted from species.species to the tree. where="root" will cause the species to be attached to the MRCA of all members of genus. where="random" will cause species to be attached at random to "phylo".genus contains only one species and where="root", then species will be attached midway along the branch leading to the one species. If where="random" then species will be added at a random position along the edge. If genus cannot be found in the tree, then the original tree is returned and a warning printed. If the tree is not ultrametric, then the resultant tree may not contain branch lengths and a warning will be printed. If genus is non-monophyletic then species will be attached to the most inclusive group containing members of genus and a warning will be printed.add.random, bind.tip