describe.simmap(tree, ...)
"summary"(object, ...)
"summary"(object, ...)
"plot"(x, ...)"simmap" or "multiSimmap", respectively."simmap" or "multiSimmap".plot method, an object of class "describe.simmap".plot, a logical value indicating whether or not to plot the posterior probabilities at nodes (default is plot=FALSE); check.equal, a logical value indicating whether or not to check if all trees are equal using all.equal.phylo (default is check.equal=FALSE); and message, a logical indicating whether or not to print an informative message to the screen (default is message=TRUE)."describe.simmap" with the following elements:if class(tree)="simmap" then the function simply returns the results of countSimmap combined with the states at each node of the tree and a matrix containing the total and relative times spent in each state on the tree.