evol.rate.mcmc(tree, x, ngen=10000, control=list())"phylo" format.names(x) should be the species names.sig1: starting value for $\sigma(1)^2$; sig2: starting value for $\sigma(2)^2$; a: starting value for a; sd1: standard deviation for the normal proposal distribution for $\sigma(1)^2$; sd2: standard deviation for the normal proposal distribution for $\sigma(2)^2$; kloc: scaling parameter for tree move proposals - $1/\lambda$ for the reflected exponential distribution; sdlnr: standard deviation on the log-normal prior on $\sigma(1)^2/\sigma(2)^2$; rand.shift: probability of proposing a random shift in the tree (improves mixing); print: print frequency for the MCMC; sample: sample frequency.control are given in Revell et al. (2012).
Revell, L. J., D. L. Mahler, P. Peres-Neto, and B. D. Redelings. (2012) A new method for identifying exceptional phenotypic diversification. Evolution, 66, 135-146.
anc.Bayes, brownie.lite, evol.vcv, minSplit, posterior.evolrate