fitDiversityModel(tree,x,d=NULL,showTree=TRUE,tol=1e-6)"phylo" format.d=NULL (the default) function will treat the diversification as if it occurred in a single geographic area.d is incremented during rescaling of psi for optimization. If R thinks your matrices are singular during optimization, try increasing tol slightly.brownie.lite, estDiversity, evol.rate.mcmc