locate.yeti(tree, X, ...)"phylo".method ("ML" or "REML", defaults to "ML"); search ("heuristic" or "exhaustive", defaults to "heuristic"); constraint, a vector containing the daughter node numbers from tree$edge for each edge to try; plot a logical argument specifying whether or not to plot the likelihood profile on edges (defaults to FALSE); rotate a logical indicating whether or not to rotate the data based on the input tree; and quiet, which is logical and has an obvious interpretation."phylo".
Revell, L. J. (2012) phytools: An R package for phylogenetic comparative biology (and other things). Methods Ecol. Evol., 3, 217-223.
Revell, L. J., D. L. Mahler, R. G. Reynolds, and G. J. Slater. (In press) Placing cryptic, recently extinct, or hypothesized taxa into an ultrametric phylogeny using continuous character data: A case study with the lizard Anolis roosevelti. Evolution.