mrp.supertree(trees, method=c("pratchet","optim.parsimony"), ...)
compute.mr(trees, type=c("phyDat","matrix"))"multiPhylo" (i.e., a list of trees).pratchet or optim.parsimony.compute.mr, the type of object to return.pratchet or optim.parsimony."phylo" or "multiPhylo" object that is the MP or set of MP MRP trees.
In the case of compute.mr, an object of class "phyDat" or a matrix.pratchet or optim.parsimony from the "phangorn" package (Schliep 2011) and prop.part from the "ape" package (Paradis et al. 2004). See pratchet or optim.parsimony for optional arguments, which vary slightly depending on the method. All optional arguments of these methods are available to the user with one exception. The argument tree in optim.parsimony is supplied instead as start. In addition to being an object of class "phylo", start can also be assigned the string values of "NJ" or "random", in which case either a neighbor-joining or random tree will be used as the starting tree for optimization.
The function compute.mr computes the matrix-representation matrix of the input trees. It is used internally by mrp.supertree, but can also be used to export an object that can be written to file if desired.exhaustiveMP, optim.parsimony, pratchet