plot.fitPagel plots the fitted models using arrows.
fitPagel(tree, x, y, method="fitMk", model="ARD", dep.var="xy", ...)
"plot"(x, ...)"phylo".tree. For S3 plot method, an object of class "fitPagel".tree.method="fitMk"). Other options are "ace" to use the ace function in ape for optimization, or to "fitDiscrete" (if the geiger package is installed) to use geiger's fitDiscrete for optimization.model="ER", "SYM" (equivalent to "ER" in this case),
and "ARD".dep.var="xy" than the rate of subsitution in x depends on y & vice versa. If dep.var="x" than the substitution rate in x depends on y, but not the converse. Finally, if dep.var="y" than the rate of substitution in y depends on x, but not the converse.fitMk, ace, or fitDiscrete. For plot method optional arguments include (but may not be limited to): signif, the number of digits for the rates to be plotted; main, a character vector of length two with the headings for each subplot; cex.main, cex.sub, cex.traits, and cex.rates, font sizes for the various text elements of the plot; and lwd.by.rate, a logical argument specifying whether or not to scale arrow line widths in proportion to the estimated rates."fitPagel" which contains the optimized matrices under an independence & a dependence model, log-likelihoods, a likelihood ratio, and a P-value for the independence model based on a chi-squared test.plot.fitPagel creates a plot showing the different fitted models with arrows.
Revell, L. J. (2012) phytools: An R package for phylogenetic comparative biology (and other things). Methods Ecol. Evol., 3, 217-223.
ace, fitMk, make.simmap