fitPagel: Function to test for correlated evolution of binary traits
Description
This function fit's Pagel's (1994) model for the correlated evolution of two binary characters.Usage
fitPagel(tree, x, y, method="fitMk", ...)
Arguments
tree
an object of class "phylo".
x
a vector of phenotypic values for a binary trait for the species in tree.
y
a second binary character for the species in tree.
method
function to use for optimization (defaults to method="fitMk"). Other options are "ace" to use the ace function in ape for optimization, or to "fitDiscrete" (if the geiger ...
optional arguments to be passed to fitMk, ace, or fitDiscrete. Value
- An object of class
"fitPagel" which contains the optimized matrices under an independence & a dependence model, log-likelihoods, a likelihood ratio, and a P-value for the independence model based on a chi-squared test.
References
Pagel, M. (1994) Detecting correlated evolution on phylogenies: A general method for the comparative analysis fo discrete characters. Proceedings of the Royal Society B, 255, 37-45.
Revell, L. J. (2012) phytools: An R package for phylogenetic comparative biology (and other things). Methods Ecol. Evol., 3, 217-223.